@@ -4,10 +4,10 @@
  *	  Tuple conversion support.
  *
  *
- * Portions Copyright (c) 1996-2010, PostgreSQL Global Development Group
+ * Portions Copyright (c) 1996-2013, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
- * $PostgreSQL: pgsql/src/include/access/tupconvert.h,v 1.3 2010/02/26 02:01:21 momjian Exp $
+ * src/include/access/tupconvert.h
  *
  *-------------------------------------------------------------------------
  */
@@ -15,6 +15,7 @@
 #define TUPCONVERT_H
 
 #include "access/htup.h"
+#include "access/tupdesc.h"
 
 
 typedef struct TupleConversionMap
